@@ -7,7 +7,9 @@ from Classification.Parameter.DeepNetworkParameter import DeepNetworkParameter
 
 class DeepNetwork(Classifier):
 
-    def train(self, trainSet: InstanceList, parameters: DeepNetworkParameter):
+    def train(self,
+              trainSet: InstanceList,
+              parameters: DeepNetworkParameter):
         """
         Training algorithm for deep network classifier.
 
@@ -18,5 +20,10 @@ class DeepNetwork(Classifier):
         parameters : DeepNetworkParameter
             Parameters of the deep network algorithm. crossValidationRatio and seed are used as parameters.
         """
-        partition = Partition(trainSet, parameters.getCrossValidationRatio(), parameters.getSeed(), True)
-        self.model = DeepNetworkModel(partition.get(1), partition.get(0), parameters)
+        partition = Partition(instanceList=trainSet,
+                              ratio=parameters.getCrossValidationRatio(),
+                              seed=parameters.getSeed(),
+                              stratified=True)
+        self.model = DeepNetworkModel(trainSet=partition.get(1),
+                                      validationSet=partition.get(0),
+                                      parameters=parameters)
