@@ -6,7 +6,9 @@ from Classification.Parameter.Parameter import Parameter
 
 class Dummy(Classifier):
 
-    def train(self, trainSet: InstanceList, parameters: Parameter):
+    def train(self,
+              trainSet: InstanceList,
+              parameters: Parameter):
         """
         Training algorithm for the dummy classifier. Actually dummy classifier returns the maximum occurring class in
         the training data, there is no training.
