@@ -8,7 +8,9 @@ from Classification.Parameter.RandomForestParameter import RandomForestParameter
 
 class RandomForest(Classifier):
 
-    def train(self, trainSet: InstanceList, parameters: RandomForestParameter):
+    def train(self,
+              trainSet: InstanceList,
+              parameters: RandomForestParameter):
         """
         Training algorithm for random forest classifier. Basically the algorithm creates K distinct decision trees from
         K bootstrap samples of the original training set.
@@ -20,10 +22,12 @@ class RandomForest(Classifier):
         parameters : RandomForestParameter
             Parameters of the bagging trees algorithm. ensembleSize returns the number of trees in the random forest.
         """
-        forestSize = parameters.getEnsembleSize()
+        forest_size = parameters.getEnsembleSize()
         forest = []
-        for i in range(forestSize):
+        for i in range(forest_size):
             bootstrap = trainSet.bootstrap(i)
-            tree = DecisionTree(DecisionNode(InstanceList(bootstrap.getSample()), None, parameters, False))
+            tree = DecisionTree(DecisionNode(data=InstanceList(bootstrap.getSample()),
+                                             parameter=parameters,
+                                             isStump=False))
             forest.append(tree)
         self.model = TreeEnsembleModel(forest)
