@@ -6,5 +6,7 @@ from Classification.Instance.Instance import Instance
 class DistanceMetric(object):
 
     @abstractmethod
-    def distance(self, instance1: Instance, instance2: Instance) -> float:
+    def distance(self,
+                 instance1: Instance,
+                 instance2: Instance) -> float:
         pass
