@@ -10,7 +10,9 @@ class MxKFoldRunSeparateTest(KFoldRunSeparateTest):
 
     M: int
 
-    def __init__(self, M: int, K: int):
+    def __init__(self,
+                 M: int,
+                 K: int):
         """
         Constructor for KFoldRunSeparateTest class. Basically sets K parameter of the K-fold cross-validation and M for
         the number of times.
@@ -41,11 +43,18 @@ class MxKFoldRunSeparateTest(KFoldRunSeparateTest):
             An ExperimentPerformance instance.
         """
         result = ExperimentPerformance()
-        instanceList = experiment.getDataSet().getInstanceList()
-        partition = Partition(instanceList, 0.25, experiment.getParameter().getSeed(), True)
+        instance_list = experiment.getDataSet().getInstanceList()
+        partition = Partition(instanceList=instance_list,
+                              ratio=0.25,
+                              seed=experiment.getParameter().getSeed(),
+                              stratified=True)
         for j in range(self.M):
-            crossValidation = KFoldCrossValidation(partition.get(1).getInstances(), self.K, experiment.getParameter().
-                                                   getSeed())
-            self.runExperiment(experiment.getClassifier(), experiment.getParameter(), result, crossValidation,
-                               partition.get(0))
+            cross_validation = KFoldCrossValidation(instanceList=partition.get(1).getInstances(),
+                                                   K=self.K,
+                                                   seed=experiment.getParameter().getSeed())
+            self.runExperimentSeparate(classifier=experiment.getClassifier(),
+                               parameter=experiment.getParameter(),
+                               experimentPerformance=result,
+                               crossValidation=cross_validation,
+                               testSet=partition.get(0))
         return result
