@@ -35,10 +35,17 @@ class StratifiedKFoldRunSeparateTest(KFoldRunSeparateTest):
             An ExperimentPerformance instance.
         """
         result = ExperimentPerformance()
-        instanceList = experiment.getDataSet().getInstanceList()
-        partition = Partition(instanceList, 0.25, experiment.getParameter().getSeed(), True)
-        crossValidation = StratifiedKFoldCrossValidation(Partition(partition.get(1)).getLists(), self.K,
-                                                         experiment.getParameter().getSeed())
-        self.runExperiment(experiment.getClassifier(), experiment.getParameter(), result, crossValidation,
-                           partition.get(0))
+        instance_list = experiment.getDataSet().getInstanceList()
+        partition = Partition(instanceList=instance_list,
+                              ratio=0.25,
+                              seed=experiment.getParameter().getSeed(),
+                              stratified=True)
+        cross_validation = StratifiedKFoldCrossValidation(instanceLists=Partition(partition.get(1)).getLists(),
+                                                         K=self.K,
+                                                         seed=experiment.getParameter().getSeed())
+        self.runExperimentSeparate(classifier=experiment.getClassifier(),
+                                   parameter=experiment.getParameter(),
+                                   experimentPerformance=result,
+                                   crossValidation=cross_validation,
+                                   testSet=partition.get(0))
         return result
