@@ -6,7 +6,9 @@ class KnnInstance(object):
     instance: Instance
     distance: float
 
-    def __init__(self, instance: Instance, distance: float):
+    def __init__(self,
+                 instance: Instance,
+                 distance: float):
         """
         The constructor that sets the instance and distance value.
 
