@@ -5,7 +5,9 @@ class ClassificationPerformance(Performance):
 
     __accuracy: float
 
-    def __init__(self, accuracy: float, errorRate: float = -1):
+    def __init__(self,
+                 accuracy: float,
+                 errorRate: float = -1):
         """
         A constructor that sets the accuracy and errorRate via given input.
 
@@ -17,9 +19,9 @@ class ClassificationPerformance(Performance):
             Double value input.
         """
         if errorRate == -1:
-            self.errorRate = 1 - accuracy
+            self.error_rate = 1 - accuracy
         else:
-            self.errorRate = errorRate
+            self.error_rate = errorRate
         self.__accuracy = accuracy
 
     def getAccuracy(self) -> float:
