@@ -5,7 +5,7 @@ from DataStructure.CounterHashMap import CounterHashMap
 class ConfusionMatrix:
 
     __matrix: dict
-    __classLabels: list
+    __class_labels: list
 
     def __init__(self, classLabels: list):
         """
@@ -16,10 +16,12 @@ class ConfusionMatrix:
         classLabels : list
             list of String.
         """
-        self.__classLabels = classLabels
+        self.__class_labels = classLabels
         self.__matrix = {}
 
-    def classify(self, actualClass: str, predictedClass: str):
+    def classify(self,
+                 actualClass: str,
+                 predictedClass: str):
         """
         The classify method takes two Strings; actual class and predicted class as inputs. If the matrix dictionary
         contains given actual class String as a key, it then assigns the corresponding object of that key to a
@@ -35,11 +37,11 @@ class ConfusionMatrix:
             String input predicted class.
         """
         if actualClass in self.__matrix:
-            counterHashMap = self.__matrix[actualClass]
+            counter_hash_map = self.__matrix[actualClass]
         else:
-            counterHashMap = CounterHashMap()
-        counterHashMap.put(predictedClass)
-        self.__matrix[actualClass] = counterHashMap
+            counter_hash_map = CounterHashMap()
+        counter_hash_map.put(predictedClass)
+        self.__matrix[actualClass] = counter_hash_map
 
     def addConfusionMatrix(self, confusionMatrix: ConfusionMatrix):
         """
@@ -52,14 +54,14 @@ class ConfusionMatrix:
         confusionMatrix : ConfusionMatrix
             ConfusionMatrix input.
         """
-        for actualClass in confusionMatrix.__matrix:
-            rowToBeAdded = confusionMatrix.__matrix[actualClass]
-            if actualClass in self.__matrix:
-                currentRow = self.__matrix[actualClass]
-                currentRow.add(rowToBeAdded)
-                self.__matrix[actualClass] = currentRow
+        for actual_class in confusionMatrix.__matrix:
+            row_to_be_added = confusionMatrix.__matrix[actual_class]
+            if actual_class in self.__matrix:
+                current_row = self.__matrix[actual_class]
+                current_row.add(row_to_be_added)
+                self.__matrix[actual_class] = current_row
             else:
-                self.__matrix[actualClass] = rowToBeAdded
+                self.__matrix[actual_class] = row_to_be_added
 
     def sumOfElements(self) -> float:
         """
@@ -72,8 +74,8 @@ class ConfusionMatrix:
             The summation of values.
         """
         result = 0
-        for actualClass in self.__matrix:
-            result += self.__matrix[actualClass].sumOfCounts()
+        for actual_class in self.__matrix:
+            result += self.__matrix[actual_class].sumOfCounts()
         return result
 
     def trace(self) -> float:
@@ -87,9 +89,9 @@ class ConfusionMatrix:
             Summation of values.
         """
         result = 0
-        for actualClass in self.__matrix:
-            if actualClass in self.__matrix[actualClass]:
-                result += self.__matrix[actualClass][actualClass]
+        for actual_class in self.__matrix:
+            if actual_class in self.__matrix[actual_class]:
+                result += self.__matrix[actual_class][actual_class]
         return result
 
     def columnSum(self, predictedClass: str) -> float:
@@ -108,9 +110,9 @@ class ConfusionMatrix:
             Summation of values.
         """
         result = 0
-        for actualClass in self.__matrix:
-            if predictedClass in self.__matrix[actualClass]:
-                result += self.__matrix[actualClass][predictedClass]
+        for actual_class in self.__matrix:
+            if predictedClass in self.__matrix[actual_class]:
+                result += self.__matrix[actual_class][predictedClass]
         return result
 
     def getAccuracy(self) -> float:
@@ -135,10 +137,10 @@ class ConfusionMatrix:
             The result of TP/FP+TP.
         """
         result = []
-        for i in range(len(self.__classLabels)):
-            actualClass = self.__classLabels[i]
-            if actualClass in self.__matrix:
-                result.append(self.__matrix[actualClass][actualClass] / self.columnSum(actualClass))
+        for i in range(len(self.__class_labels)):
+            actual_class = self.__class_labels[i]
+            if actual_class in self.__matrix:
+                result.append(self.__matrix[actual_class][actual_class] / self.columnSum(actual_class))
         return result
 
     def recall(self) -> list:
@@ -152,10 +154,10 @@ class ConfusionMatrix:
             The result of TP/FN+TP.
         """
         result = []
-        for i in range(len(self.__classLabels)):
-            actualClass = self.__classLabels[i]
-            if actualClass in self.__matrix:
-                result.append(self.__matrix[actualClass][actualClass] / self.__matrix[actualClass].sumOfCounts())
+        for i in range(len(self.__class_labels)):
+            actual_class = self.__class_labels[i]
+            if actual_class in self.__matrix:
+                result.append(self.__matrix[actual_class][actual_class] / self.__matrix[actual_class].sumOfCounts())
         return result
 
     def fMeasure(self) -> list:
@@ -171,7 +173,7 @@ class ConfusionMatrix:
         precision = self.precision()
         recall = self.recall()
         result = []
-        for i in range(len(self.__classLabels)):
+        for i in range(len(self.__class_labels)):
             result.append(2 / (1 / precision[i] + 1 / recall[i]))
         return result
 
@@ -185,9 +187,9 @@ class ConfusionMatrix:
         float
             The weighted average of recall and precision.
         """
-        fMeasure = self.fMeasure()
+        f_measure = self.fMeasure()
         total = 0
-        for i in range(len(self.__classLabels)):
-            actualClass = self.__classLabels[i]
-            total += fMeasure[i] * self.__matrix[actualClass].sumOfCounts()
+        for i in range(len(self.__class_labels)):
+            actual_class = self.__class_labels[i]
+            total += f_measure[i] * self.__matrix[actual_class].sumOfCounts()
         return total / self.sumOfElements()
